@@ -5,9 +5,10 @@ Results are parsed into usable format, and then written to a postgres database.
 """
 from io import BytesIO
 import asyncio
+import logging
 from datetime import datetime
 from math import sqrt, cos, sin, radians
-from typing import Iterable, Optional, Any, Dict, List, Sequence, Tuple
+from typing import Optional, Any, Dict, List, Sequence
 import time
 import struct
 from multiprocessing import Process
@@ -304,6 +305,7 @@ async def line_to_obj(raw_line: bytearray, ref: Ref) -> Optional[ObjectRec]:
     """Parse a textline from tacview into an ObjectRec."""
     # secondary_update = None
     if raw_line[0:1] == b"0":
+        LOG.debug("Raw line starts with 0...")
         return None
 
     if raw_line[0:1] == b'-':
@@ -668,6 +670,7 @@ async def consumer(host: str,
     while True:
         try:
             obj = await sock.read_stream()
+            LOG.debug(obj)
             lines_read += 1
 
             if not sock.all_refs:
@@ -693,7 +696,6 @@ async def consumer(host: str,
                             lines_read, ln_sec))
                         print_log = runtime
 
-
             else:
                 t1 = time.time()
                 obj = await line_to_obj(obj, sock)
@@ -768,6 +770,8 @@ async def check_results():
 def main(host, port, max_iters, batch_size, dsn, debug=False):
     """Start event loop to consume stream."""
     uvloop.install()
+    if debug:
+        LOG.setLevel(logging.DEBUG)
     asyncio.run(consumer(host, port, max_iters, batch_size, dsn))
 
 
